<!DOCTYPE html>
<html lang="en">
<head>
  {% block head %}
  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <meta name="generator" content="pytest-reporter-html-dots {{ __version__ }}">
  <title>{{ title|default('Test Report') }}</title>
  {% filter css %}
    {% filter css_minify %}
      {% block style %}
      {% include "html-dots/normalize.css" %}
      {% include "html-dots/style.css" %}
      {% endblock %}
    {% endfilter %}
  {% endfilter %}
  <script>
    {% block script %}
    {% endblock %}
  </script>
  {% endblock %}
</head>
<body>
  <header>
    {% block header %}
    <div class="container">
      <span class="report-title">{{ title|default('Test Report') }}</span>
    </div>
    {% endblock %}
  </header>
  <main>
    {% block content %}{% endblock %}
  </main>
  <footer>
    {% block footer %}
    <div class="container">
      Generated by <a href="https://pypi.org/project/pytest-reporter-html-dots/">pytest-reporter-html-dots</a>
    </div>
    {% endblock %}
  </footer>
</body>
</html>
